@@ -1,3 +1,36 @@
+"""FotonPC
+Robin Interpter
+example:
+    x=1
+    y=x*3+2
+    печать y+x
+print - печать
+goto - строка
+if - если
+
+exaple:
+    i=0
+    печать i
+    i=i+1
+    если (i<101):строка 2
+    x=13;печать x*y
+result:
+    1
+    2
+    3
+    4
+    5
+    6
+    7
+    8
+    9
+    10
+    11
+    12
+    13
+    ...
+    99
+    100"""
 import random
 def is_error(obj):
     try:
@@ -43,12 +76,12 @@ class data:
         while i<len(self.date):
             if self.date[i][1]==n:
                 self.date[i][3]=v
+                return None
             i+=1
         Ro_NameError(l,"Нет имени "+n+'!',s,p=list(s).index(n))
     def value_re_with_id(self,i,v): pass
     def id_re_with_name(self,n,i): pass
     def name_re_with_id(self,i,n): pass
-    def value_re_with_name(self,n,v): pass
     def type_re_with_id(self,i,t): pass
     def type_re_with_name(self,n,t): pass
     def find_value_with_name(self,n,line,string):
@@ -57,9 +90,11 @@ class data:
             if self.date[i][1]==n:
                 return self.date[i][3]
             i+=1
-        Ro_NameError(line,"Нет имени "+n+'!',string,p=list(string).index(n))
+        Ro_NameError(line,"Нет имени "+n+'!',string,p=list(string.replace(n,'p')).index(n))
     def add_object(self,obj):
         self.date+=[obj]
+    def __str__(self):
+        return str(self.date)
     
 class Robin:
     def __init__(self):
@@ -67,9 +102,24 @@ class Robin:
     def load(self,ert):
         self.eexece(ert)
     def eexece(self,code):
+        code=code.replace(';','\n')
         self.exec(code)
     def error(self,e):
         e.out()
+    def boolexex(self,bex,l,string):
+        sc=string
+        exc=bex
+        for c in list('.+-*/%1234567890>=<!'):
+            try:
+                exc=exc.replace(c," ")
+            except: pass
+        exc=exc.split()
+        for nm in exc:
+            bex=bex.replace(nm,str(self.data.find_value_with_name(nm,l,sc)))
+        bex=bex.replace('не','not')
+        bex=bex.replace('и','and')
+        bex=bex.replace('или','or')
+        return bex
     def exex(self,ex,l,string):
         sc=string
         exc=ex
@@ -81,10 +131,58 @@ class Robin:
         for nm in exc:
             ex=ex.replace(nm,str(self.data.find_value_with_name(nm,l,sc)))
         return ex
-    def exec(self,codepart):
+    def exec(self,codepart,line=0,lines=None):
         codepartlist=list(codepart.split("\n"))
-        i=0
-        while i<len(codepartlist):
+        i=line
+        if(lines==None):
+            lines=len(codepartlist)
+        while i<lines:
+            if ' ' in codepartlist[i]:
+                string=codepartlist[i]
+                oper=string.split()[0]
+                if oper=='строка':
+                    try:
+                        i=int(string.split()[1])-2
+                    except:
+                        Ro_SintaxError(i+1,'Должно быть число',string)
+                if oper=='печать':
+                    #if True:
+                    try:
+                        print(eval(self.exex(string.split()[1],i+1,string)))
+                    except:
+                        Ro_SintaxError(i+1,'',string) 
+                if oper=='если':
+                    n=string.index(':')
+                    s1=string.index('(')
+                    s2=string.index(')')
+                    #if True:
+                    try:
+                        if(bool(eval(self.boolexex(string[s1+1:s2:],i+1,string)))):
+                            strin=string[n+1::]
+                            if ' ' in strin:
+                                oper=strin.split()[0]
+                                if oper=='строка':
+                                    try:
+                                        i=int(strin.split()[1])-2
+                                    except:
+                                        Ro_SintaxError(i+1,'Должно быть число',strin)
+                                if oper=='печать':
+                                    #if True:
+                                    try:
+                                        print(eval(self.exex(strin.split()[1],i+1,strin)))
+                                    except:
+                                        Ro_SintaxError(i+1,'',strin) 
+                            if "=" in strin:
+                                strlist=strin.split("=")
+                                #if(True):
+                                try:
+                                    es=eval(self.exex(strlist[1],i+1,strin))
+                                    self.new_object(strlist[0],'int',es,i+1,strin)
+                                except: Ro_SintaxError(i+1,'',strin)
+                    except:
+                        Ro_SintaxError(i+1,'',string)
+                i+=1
+                continue
             if "=" in codepartlist[i]:
                 string=codepartlist[i]
                 strlist=string.split("=")
@@ -93,20 +191,7 @@ class Robin:
                     es=eval(self.exex(strlist[1],i+1,string))
                     self.new_object(strlist[0],'int',es,i+1,string)
                 except: Ro_SintaxError(i+1,'',string)
-            if ' ' in codepartlist[i]:
-                string=codepartlist[i]
-                oper=string.split()[0]
-                if oper=='строка':
-                    try:
-                        i=int(string[1])-1
-                    except:
-                        Ro_SintaxError(i+1,'Должно быть число',string)
-                if oper=='печать':
-                    if True:
-                    #try:
-                        print(eval(self.exex(string.split()[1],i+1,string)))
-                    #except:
-                        #Ro_SintaxError(i+1,'',string)
+            
             i+=1
     def new_object(self, name,typeo,value,line,string):
         if name in self.data.names():
